@@ -122,6 +122,10 @@
 #ifndef CONFIGFILE
 #define CONFIGFILE	"/etc/prngd.conf"
 #endif
+#ifndef SOCKETMODE
+#define SOCKETMODE	0777
+#endif
+
 
 #define BITS_PER_BYTE	8
 
